==> reakit-0.13.1.tgz: package/es/Tooltip.js <==
import React from 'react';
import { findDOMNode } from 'react-dom';
import styled from 'styled-components';
import { prop } from 'styled-tools';
import { a as as, b as classCallCheck, c as inherits, d as objectWithoutProperties, e as possibleConstructorReturn, f as _extends } from './as-8a1cd76d.js';
import Popover from './Popover.js';
import { a as PopoverArrow } from './chunk-271f4c74.js';
import 'lodash-es/uniq';
import 'react-known-props';
import 'lodash-es/omit';
import 'prop-types';
import 'popper.js';
import './Hidden.js';
import './chunk-84d8695a.js';
import 'hoist-non-react-statics';
import './chunk-fa81e9f1.js';
import './Base.js';
import './chunk-a29c7f2d.js';
import 'lodash-es/kebabCase';
import './chunk-3cd03ec9.js';
import 'constate';
import './chunk-60576777.js';
import './Box.js';
import 'lodash-es/uniqueId';
import './Arrow.js';

/* eslint-disable react/no-find-dom-node, react/no-unused-state */

var Component = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component() {
    var _temp, _this, _ret;

    classCallCheck(this, Component);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.state = {
      visible: false
    }, _this.isControlled = function () {
      return typeof _this.props.visible !== "undefined";
    }, _this.show = function () {
      return _this.setState({ visible: true });
    }, _this.hide = function () {
      return _this.setState({ visible: false });
    }, _this.getTooltip = function () {
      return findDOMNode(_this);
    }, _temp), possibleConstructorReturn(_this, _ret);
  }

  Component.prototype.componentDidMount = function componentDidMount() {
    var _getTooltip = this.getTooltip(),
        parentNode = _getTooltip.parentNode;

    if (parentNode && !this.isControlled()) {
      parentNode.addEventListener("mouseenter", this.show);
      parentNode.addEventListener("focus", this.show);
      parentNode.addEventListener("mouseleave", this.hide);
      parentNode.addEventListener("blur", this.hide);
    }
  };

  Component.prototype.componentWillUnmount = function componentWillUnmount() {
    var _getTooltip2 = this.getTooltip(),
        parentNode = _getTooltip2.parentNode;

    if (parentNode) {
      parentNode.removeEventListener("mouseenter", this.show);
      parentNode.removeEventListener("focus", this.show);
      parentNode.removeEventListener("mouseleave", this.hide);
      parentNode.removeEventListener("blur", this.hide);
    }
  };

  Component.prototype.render = function render() {
    var _ref = this.isControlled() ? this.props : this.state,
        visible = _ref.visible;

    return React.createElement(Popover, _extends({}, this.props, { visible: visible }));
  };

  return Component;
}(React.Component);

var Tooltip = styled(Component).withConfig({
  displayName: "Tooltip"
})(["pointer-events:none;white-space:nowrap;text-transform:none;font-size:0.875em;text-align:center;color:white;background-color:#222;border-radius:0.15384em;padding:0.75em 1em;", ";"], prop("theme.Tooltip"));

Tooltip.defaultProps = {
  role: "tooltip",
  placement: "top"
};

var Tooltip$1 = as("div")(Tooltip);

var TooltipArrow = styled(PopoverArrow).withConfig({
  displayName: "TooltipArrow"
})(["color:#222;border:none;", ";"], prop("theme.TooltipArrow"));

var TooltipArrow$1 = as("div")(TooltipArrow);

Tooltip$1.Arrow = TooltipArrow$1;

export default Tooltip$1;

==> reakit-0.13.2.tgz: package/es/Tooltip.js <==
import React from 'react';
import { findDOMNode } from 'react-dom';
import styled from 'styled-components';
import { prop } from 'styled-tools';
import { a as as, b as classCallCheck, c as inherits, d as objectWithoutProperties, e as possibleConstructorReturn, f as _extends } from './as-fe550043.js';
import Popover from './Popover.js';
import { a as PopoverArrow } from './chunk-f05e0d0b.js';
import 'lodash-es/uniq';
import 'react-known-props';
import 'lodash-es/omit';
import 'prop-types';
import 'popper.js';
import './Hidden.js';
import './chunk-84d8695a.js';
import 'hoist-non-react-statics';
import './chunk-fa81e9f1.js';
import './Base.js';
import './chunk-a29c7f2d.js';
import 'lodash-es/kebabCase';
import './chunk-10d4a0a3.js';
import 'constate';
import './chunk-5093c559.js';
import './Box.js';
import 'lodash-es/uniqueId';
import './Arrow.js';

/* eslint-disable react/no-unused-state */

var Component = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component() {
    var _temp, _this, _ret;

    classCallCheck(this, Component);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.state = {
      visible: false
    }, _this.isControlled = function () {
      return typeof _this.props.visible !== "undefined";
    }, _this.show = function () {
      return _this.setState({ visible: true });
    }, _this.hide = function () {
      return _this.setState({ visible: false });
    }, _this.getTooltip = function () {
      return findDOMNode(_this);
    }, _temp), possibleConstructorReturn(_this, _ret);
  }

  Component.prototype.componentDidMount = function componentDidMount() {
    var _getTooltip = this.getTooltip(),
        parentNode = _getTooltip.parentNode;

    if (parentNode && !this.isControlled()) {
      parentNode.addEventListener("mouseenter", this.show);
      parentNode.addEventListener("focus", this.show);
      parentNode.addEventListener("mouseleave", this.hide);
      parentNode.addEventListener("blur", this.hide);
    }
  };

  Component.prototype.componentWillUnmount = function componentWillUnmount() {
    var _getTooltip2 = this.getTooltip(),
        parentNode = _getTooltip2.parentNode;

    if (parentNode) {
      parentNode.removeEventListener("mouseenter", this.show);
      parentNode.removeEventListener("focus", this.show);
      parentNode.removeEventListener("mouseleave", this.hide);
      parentNode.removeEventListener("blur", this.hide);
    }
  };

  Component.prototype.render = function render() {
    var _ref = this.isControlled() ? this.props : this.state,
        visible = _ref.visible;

    return React.createElement(Popover, _extends({}, this.props, { visible: visible }));
  };

  return Component;
}(React.Component);

var Tooltip = styled(Component).withConfig({
  displayName: "Tooltip"
})(["pointer-events:none;white-space:nowrap;text-transform:none;font-size:0.875em;text-align:center;color:white;background-color:#222;border-radius:0.15384em;padding:0.75em 1em;", ";"], prop("theme.Tooltip"));

Tooltip.defaultProps = {
  role: "tooltip",
  placement: "top"
};

var Tooltip$1 = as("div")(Tooltip);

var TooltipArrow = styled(PopoverArrow).withConfig({
  displayName: "TooltipArrow"
})(["color:#222;border:none;", ";"], prop("theme.TooltipArrow"));

var TooltipArrow$1 = as("div")(TooltipArrow);

Tooltip$1.Arrow = TooltipArrow$1;

export default Tooltip$1;
